# Various Python utilities

This is my personal utilities package.

This will contain, over time, an assortment of utilities that I find useful in
various projects.

There's a story behind the package name, but it's not actually that interesting
:-)
